<?php

namespace Drupal\config_entity_cloner\Plugin\config_entity_cloner\ConfigEntityClonerProcess;

use Drupal\config_entity_cloner\PluginManager\ConfigEntityClonerProcess\ConfigEntityClonerProcessInterface;
use Drupal\config_entity_cloner\Service\ConfigEntityCloner;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation For the type processor.
 *
 * @ConfigEntityClonerProcessAnnotation(
 *   id = "rabbit_hole",
 *   label = "Rabbit Hole",
 *   weight = 30
 * )
 */
class RabbitHoleConfigEntityClonerProcess implements ConfigEntityClonerProcessInterface {

  /**
   * Logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * SimpleSiteMapCloneProcess constructor.
   *
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   THe config factory.
   */
  public function __construct(LoggerInterface $logger, ConfigFactoryInterface $configFactory) {
    $this->logger = $logger;
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): ConfigEntityClonerProcessInterface {
    return new static(
      $container->get('logger.factory')->get(ConfigEntityCloner::SERVICE_NAME),
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function cloneProcess(EntityInterface $newEntity, EntityInterface $originalEntity): void {
    /** @var \Drupal\rabbit_hole\BehaviorSettingsManagerInterface $behaviorsSettingsManager */
    if( $behaviorsSettingsManager = \Drupal::service('rabbit_hole.behavior_settings_manager') ){
      $originalSettings = $behaviorsSettingsManager->loadBehaviorSettingsAsConfig($originalEntity->getEntityTypeId(), $originalEntity->id());
      $rawData = $originalSettings->getRawData();
      unset($rawData['uuid']);
      unset($rawData['dependencies']);
      unset($rawData['entity_id']);
      unset($rawData['entity_type_id']);
      $behaviorsSettingsManager->saveBehaviorSettings($rawData, $newEntity->getEntityTypeId(), $newEntity->id());
    }
  }

}
